# Les parcours du BUT dans ScoDoc
Cette documentation est destinée aux développeurs et à tous ceux qui souhaitent
comprendre le fonctionnement du logiciel.

ScoDoc est livré avec les référentiels de compétences de tous les parcours de toutes
les spécialités de BUT. En effet, ces référentiels sont nationaux, publiés par
le ministère (voir
[https://cache.media.enseignementsup-recherche.gouv.fr/file/SPE4-MESRI-17-6-2021/32/3/_Annexe_1_PN_BUT_version_post_CNESER_20210511_18-05-2021-1_1411323.pdf](https://cache.media.enseignementsup-recherche.gouv.fr/file/SPE4-MESRI-17-6-2021/32/3/_Annexe_1_PN_BUT_version_post_CNESER_20210511_18-05-2021-1_1411323.pdf))
et ne sont pas susceptibles d'adaptations locales.

Nous nous sommes basés sur les versions exportées du logiciel Orébut.

## Rappel général sur le BUT et ScoDoc
Rappel simplifié, se concentrant sur les points utiles pour l'évaluation
et les liens avec le cursus de formation:

 - Chaque parcours de BUT est défini par un ensemble de compétences.
 - Une compétence est décomposée en deux ou trois *niveaux*, chacun constitué de
   deux UE consécutives (sur semestres pair et impair de la même année
   scolaire).
 - Les UE sont des UE "LMD" habituelles; associées à des crédits ECTS,
   capitalisables. Chaque UE est associée à une note (moyenne d'UE) et une
   décision de jury (validée, ajournée, ...).

Dans le BUT, le référentiel de formation n'est pas fixé nationalement. Une part
est publiée (2/3) par le ministère, le reste est défini localement par les
universités (*adaptation locale*).

Les modules: on appelle ici "module" tout dispositif pédagogique évalué, dans le
BUT ce sont les *ressources* et les *SAÉ*.

Dans ScoDoc, le programme pédagogique définit les UE et modules pour l'ensemble
des semestres d'un ou plusieurs parcours. De cette façon, on pourra utiliser les
mêmes éléments dans plusieurs parcours, et grouper les étudiants de plusieurs
parcours dans le même semestre si on le souhaite.

## Modélisation ScoDoc

On a d'une part le *programme de formation*, et de l'autre le *référentiel de
compétences*.

### Programme de formation
Le programme de formation est constitué des classes suivantes (en BUT et dans
tous les types de formation. La notion de "matière" n'est pas utilisée en BUT).

 - Formation (ex: "BUT R&T")
    - UniteEns (UE, ex: "Administrer les réseaux")
        - Modules (ressources, SAÉs) *<-> ApcAppCritique*

On voit que les modules ont toujours une UE de rattachement. Cependant, en BUT,
un module peut intervenir dans le calcul des notes de plusieurs UE, via une
matrice de coefficients.

### Référentiel de compétences
Le référentiel de compétences est structuré par les classes suivantes:

 - ApcReferentielCompetences
    - ApcCompetence
        - ApcSituationPro
        - ApcComposanteEssentielle
        - ApcNiveau (année, ordre)
            - ApcAppCritique *<-> Module*
    - ApcParcours
        - ApcAnneeParcours
            - ApcParcoursNiveauCompetence

Notons le lien entre les apprentissages critiques (ApcAppCritique) et les
modules, qui permet d'établir les critères d'évaluation de chaque module.

### FormSemestres
La formation est mise en œuvre dans des FormSemestre (date début, fin,
enseignants responsables, ...) constitués de ModuleImpl (module avec enseignant,
évaluations, ...).

 - FormSemestre
    - ModuleImpl
        - Evaluation

### Inscriptions des étudiants
Les étudiants sont inscrits:

 - dans un FormSemestre (FormSemestreInscription, avec état (I, D, DEF) et étape
   Apogée)
 - dans un ModuleImpl (ModuleImplInscription)
 - et, pour le BUT, dans un ApcParcours (TODO)

### Associations (nouvelles pour le BUT):

Pour la gestion des parcours BUT, il faut introduire les associations suivantes,
qui n'existent pas dans ScoDoc 9.2:

 - Module <-> ApcAppCritique : choix sur la page `module_edit`
 - UE <-> ApcParcoursNiveauCompetence : choix sur la page `ue_edit`
 - FormSemestre <-> ApcParcours : choix sur la page
   `formsemestre_editwithmodules`
 - Identite <-> ApcParcours : inscription au parcours, page à créer. 

### Cas d'usage

#### Inscription d'un étudiant aux ModuleImpls
L'inscription reste libre (chaque individu peut être inscrit à un sous-ensemble
quelconque des ModuleImpl du FormSemestre), mais il sera commode de pouvoir:

 - créer des groupes de parcours
 - inscrire les étudiants d'un groupe à tous les modules du parcours.

#### Comment ScoDoc détermine-t-il les modules d'un parcours ? 
Un parcours étant associé à des compétences, et les niveaux compétences à des
UE, on peut déterminer, pour un semestre de rang donné, l'ensemble des UE
associées à un parcours.

Par ailleurs, chaque niveau de compétence est associé à un ensemble d'AC
(ApcAppCritique), et chaque module est aussi associé à son ensemble d'AC.

Pour chaque parcours d'un FormSemestre, on déterminera l'ensemble des ModuleImpl
de ce semestre ayant des AC communs avec ceux des niveaux de compétences
associés aux UE du semestre (sic). Notons que les niveaux de compétences sont
annuels, mais que les ModuleImpl sont semestriels.

#### Vérifier que les ModuleImpls d'un parcours couvrent l'ensemble de ses ACs

...ou du parcours d'un étudiant donné

TBD

#### Lister les regroupements d'UE d'un étudiant

Pour une année donnée: l'étudiant est inscrit dans ScoDoc soit dans le semestre
impair, soit pair, soit les deux (il est rare mais pas impossible d'avoir une
inscription seulement en semestre pair, par exemple suite à un transfert ou un
arrêt temporaire du cursus).

 1. Déterminer l'*autre* semestre: semestre précédent ou suivant de la même
    année, formation compatible (code formation identique ou bien même
    référentiel de compétence ?) dans lequel l'étudiant est inscrit.
  
 2. Construire les couples d'UE (regroupements cohérent): apparier les UE qui
    ont le même ApcParcoursNiveauCompetence.

#### Déterminer si un étudiant peut passer dans l'année suivante

Note: on peut bien sûr toujours forcer le passage, pour traiter les cas
particuliers (décision de jury manuelle).

**Rappel:** le passage est de droit si

 - [x] plus de la moitié des niveaux de compétences de l'année sont validés
 - [x] aucun regroupement d'UE (niveau de compétence) de l'année < 8 /20
 - [x] pour le passage en S5, avoir validé toutes les UE du BUT 1 (S1 et S2).




